@@ -187,7 +187,7 @@ def featureExpressionSig(cluster1, projectionName, featureNumber, alpha, mu=0):
 def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbose=0, display=True):
     """
     Creates Bonferroni corrected Confidence intervals for the difference of the means of cluster1 and cluster2
-    :param display:
+    :param display: Whether to display CIs or not
     :param verbose: Whether to print out genes and CIs or not. 0 for print out. !=0 for no printing.
     :param cluster1: Anndata containing cluster1 cells
     :param cluster2: Anndata containing cluster2 cells
@@ -199,13 +199,17 @@ def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbo
 
     if scipy.sparse.issparse(cluster1.X):
         C1Mean = cluster1.X.mean(axis=0)
+        print("C1 is sparse")
     else:
         C1Mean = np.mean(cluster1.X, axis=0, keepdims=True)
+        print("C1 is dense")
 
     if scipy.sparse.issparse(cluster2.X):
         C2Mean = cluster2.X.mean(axis=0)
+        print("C2 is sparse")
     else:
         C2Mean = np.mean(cluster2.X, axis=0, keepdims=True)
+        print("C2 is dense")
 
     # C1Mean = np.mean(cluster1.X, axis=0, keepdims=True)
     # C2Mean = np.mean(cluster2.X, axis=0, keepdims=True)
